..  Copyright (C)  Brad Miller, David Ranum
    This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License. To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/4.0/.


Key Terms
---------

============================= ========================== ======================= 
         balanced parentheses  last in, first out (LIFO)                 postfix
                   data field      linear data structure              precedence
                        deque                linked list                  prefix
   first in, first out (FIFO)      linked list traversal                   queue
          fully parenthesized                       list              simulation
                         head                       node                   stack
                        infix                 palindrome
============================= ========================== ======================= 

